# Solidus Reviews

[![CircleCI](https://circleci.com/gh/solidusio-contrib/solidus_reviews.svg?style=svg)](https://circleci.com/gh/solidusio-contrib/solidus_reviews)

Straightforward review/rating functionality, updated for [Solidus](https://solidus.io).

While the gem's name has changed, the module namespace and commands are still `spree` for now.

## Installation

Add the following to your `Gemfile` to install from git:

```ruby
gem 'solidus_reviews', github: 'solidusio-contrib/solidus_reviews'
```

Now bundle up with:

```console
$ bundle
```

Next, run the rake task that copies the necessary migrations and assets to your project:

```console
$ rails g solidus_reviews:install
```

And finish with a migrate:

```console
$ rake db:migrate
```

Now you should be able to boot up your server with:

```console
$ rails s
```

That's all!

## Usage

The `Spree::ReviewsController` controller provides all the CRUD functionality for product reviews.

The `Spree::FeedbackReviewsController` allows user to express their feedback on a specific review.
You can think of these as meta-reviews (e.g. the classic "Was this useful?" modal).

You can approve, edit and delete reviews and feedback reviews from the backend.

## Factories

If you want factories for our models available in your application, simply require our factories in
your `spec_helper.rb`:

```ruby
require 'solidus_reviews/factories'
```

### Testing the extension

First bundle your dependencies, then run `bin/rake`. `bin/rake` will default to building the dummy

app if it does not exist, then it will run specs. The dummy app can be regenerated by using
`bin/rake extension:test_app`.

```shell
bin/rake
```

To run [Rubocop](https://github.com/bbatsov/rubocop) static code analysis run

```shell
bundle exec rubocop
```

### Running the sandbox

To run this extension in a sandboxed Solidus application, you can run `bin/sandbox`. The path for

the sandbox app is `./sandbox` and `bin/rails` will forward any Rails commands to
`sandbox/bin/rails`.

Here's an example:

```
$ bin/rails server
=> Booting Puma
=> Rails 6.0.2.1 application starting in development
* Listening on tcp://127.0.0.1:3000
Use Ctrl-C to stop
```

### Updating the changelog

Before and after releases the changelog should be updated to reflect the up-to-date status of
the project:
```shell

bin/rake changelog
git add CHANGELOG.md
git commit -m "Update the changelog"
```

## Contributing

Bug reports and pull requests are welcome on GitHub at <https://github.com/solidusio-contrib/solidus_reviews>.

## License

Copyright (c) 2009-2020 [Solidus](https://github.com/solidusio) and [contributors](https://github.com/solidusio-contrib/solidus_reviews/graphs/contributors),
released under the [New BSD License](https://github.com/solidusio-contrib/solidus_reviews/blob/master/LICENSE.md).
